@@ -76,7 +76,8 @@ for my $infile (@ARGV_infiles) {
     }
 
     if ($ARGV_from_consense) {
-        $tree->switch_branch_lengths_and_labels_for_entities;
+        my $bl = $ARGV_arb ? 1 : undef;     # treeplot wants branch lengths
+        $tree->switch_branch_lengths_and_labels_for_entities($bl);
     }
 
     if ($ARGV_ultrametrize) {
@@ -162,7 +163,7 @@ format-tree.pl - Format trees for printing
 
 =head1 VERSION
 
-version 0.181120
+version 0.181170
 
 =head1 USAGE
 
